@@ -20,7 +20,7 @@ class JenkinsClient(Jenkins):
                  verify: bool = True,
                  timeout: Optional[float] = None,
                  retry: Optional[dict] = None
-                 ):
+                 ) -> None:
         """
         Jenkins sync client class.
 
@@ -29,7 +29,7 @@ class JenkinsClient(Jenkins):
                 URL of Jenkins server.
 
             user (Optional[str]):
-                User name, login.
+                User name.
 
             password (Optional[str]):
                 Password for user.
@@ -110,7 +110,7 @@ class JenkinsClient(Jenkins):
             total=retry['total'],
             backoff_factor=retry.get('factor', 1),
             status_forcelist=retry.get('statuses', []),
-            method_whitelist=['GET', 'POST', 'PATCH'],
+            allowed_methods=retry.get('methods', ['GET', 'POST', 'PATCH']),
         ))
 
         self.session.mount('http://', adapter)
@@ -120,7 +120,7 @@ class JenkinsClient(Jenkins):
                       method: str,
                       path: str,
                       *,
-                      callback: Optional[Callable] = None,
+                      _callback: Optional[Callable] = None,
                       **kwargs: Any
                       ) -> Any:
 
@@ -134,14 +134,13 @@ class JenkinsClient(Jenkins):
         response = self.session.request(
             method,
             f'{self.host}{path}',
-            allow_redirects=False,
             verify=self.verify,
             **kwargs
         )
 
         result = self._process(
             Response(response.status_code, response.headers, response.text),
-            callback
+            _callback
         )
 
         return result
