@@ -4,7 +4,7 @@ from collections import namedtuple
 from http import HTTPStatus
 from typing import Any, Callable, Optional, Tuple
 
-from ujenkins.endpoints import Builds, Nodes, System
+from ujenkins.endpoints import Builds, Jobs, Nodes, Plugins, System, Views
 from ujenkins.exceptions import JenkinsError, JenkinsNotFoundError
 
 Response = namedtuple('Response', ['status', 'headers', 'body'])
@@ -12,14 +12,16 @@ Response = namedtuple('Response', ['status', 'headers', 'body'])
 
 class Jenkins:
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.builds = Builds(self)
+        self.jobs = Jobs(self)
         self.nodes = Nodes(self)
+        self.plugins = Plugins(self)
         self.system = System(self)
+        self.views = Views(self)
 
     @staticmethod
     def _process(response: Response, callback: Optional[Callable] = None) -> Any:
-
         if response.status == HTTPStatus.NOT_FOUND:
             raise JenkinsNotFoundError(response.body)
 
@@ -27,7 +29,8 @@ class Jenkins:
             if response.status in (
                     HTTPStatus.UNAUTHORIZED,
                     HTTPStatus.FORBIDDEN,
-                    HTTPStatus.INTERNAL_SERVER_ERROR):
+                    HTTPStatus.INTERNAL_SERVER_ERROR
+            ):
                 details = 'probably authentication problem:\n' + response.body
             else:
                 details = '\n' + response.body
@@ -44,7 +47,7 @@ class Jenkins:
         if 'application/json' in response.headers.get('Content-Type', ''):
             return json.loads(response.body)
 
-        return response.body
+        return None
 
     @staticmethod
     def _get_folder_and_job_name(name: str) -> Tuple[str, str]:
@@ -66,3 +69,7 @@ class Jenkins:
 
         if retry.get('total', 0) <= 0:
             raise JenkinsError('Invalid `total` in retry argument must be > 0')
+
+    @staticmethod
+    def _return_body(response: Response) -> str:
+        return response.body
