@@ -1,29 +1,42 @@
 import json
 
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Union
 
 
 class Builds:
+    """
+    List of Jenkins tags which can be used insted of build_id number.
 
-    def __init__(self, jenkins):
+    - lastBuild
+    - lastCompletedBuild
+    - lastFailedBuild
+    - lastStableBuild
+    - lastSuccessfulBuild
+    - lastUnstableBuild
+    - lastUnsuccessfulBuild
+    """
+    def __init__(self, jenkins) -> None:
         self.jenkins = jenkins
 
     def get(self, name: str) -> List[dict]:
         """
         Get list of builds for specified job.
 
+        Example:
+
+        .. code-block:: python
+
+            builds = [
+                {'number': 1, 'url': 'http://localhost/job/test/1/'},
+                {'number': 2, 'url': 'http://localhost/job/test/2/'}
+            ]
+
         Args:
-            name (str): job name or path (if in folder).
+            name (str):
+                Job name or path (if in folder).
 
         Returns:
             List: list of build for specified job.
-
-            .. code-block:: python
-
-                builds = [
-                  {'number': 1, 'url': 'http://localhost/job/test/1/'},
-                  {'number': 2, 'url': 'http://localhost/job/test/2/'}
-                ]
         """
         def callback(response) -> List[dict]:
             return json.loads(response.body)['allBuilds']
@@ -33,16 +46,19 @@ class Builds:
         return self.jenkins._request(
             'GET',
             f'/{folder_name}/job/{job_name}/api/json?tree=allBuilds[number,url]',
-            callback=callback,
+            _callback=callback,
         )
 
-    def get_info(self, name: str, build_id: int) -> dict:
+    def get_info(self, name: str, build_id: Union[int, str]) -> dict:
         """
         Get detailed information about specified build number of job.
 
         Args:
-            name (str): job name or path (if in folder).
-            build_id (int): build identifier.
+            name (str):
+                Job name or path (if in folder).
+
+            build_id (int):
+                Build number or some of standard tags like `lastBuild`.
 
         Returns:
             dict: information about build.
@@ -54,13 +70,16 @@ class Builds:
             f'/{folder_name}/job/{job_name}/{build_id}/api/json'
         )
 
-    def get_output(self, name: str, build_id: int) -> str:
+    def get_output(self, name: str, build_id: Union[int, str]) -> str:
         """
         Get console output of specified build.
 
         Args:
-            name (str): job name or path (if in folder).
-            build_id (int): build identifier.
+            name (str):
+                Job name or path (if in folder).
+
+            build_id (int):
+                Build number or some of standard tags like `lastBuild`.
 
         Returns:
             str: build output.
@@ -69,7 +88,8 @@ class Builds:
 
         return self.jenkins._request(
             'GET',
-            f'/{folder_name}/job/{job_name}/{build_id}/consoleText'
+            f'/{folder_name}/job/{job_name}/{build_id}/consoleText',
+            _callback=self.jenkins._return_body,
         )
 
     def start(self,
@@ -84,9 +104,14 @@ class Builds:
         https://www.jenkins.io/blog/2010/08/11/quiet-period-feature/
 
         Args:
-            name (str): job name or path (if in folder).
-            parameters (int): parameters of triggering build.
-            delay (int): delay before start.
+            name (str):
+                Job name or path (if in folder).
+
+            parameters (int):
+                Parameters of triggering build.
+
+            delay (int):
+                Delay before start.
 
         Returns:
             Optional[int]: queue item id.
@@ -129,18 +154,21 @@ class Builds:
         return self.jenkins._request(
             'POST',
             path,
-            callback=callback,
             params={'delay': delay},
             data=data,
+            _callback=callback,
         )
 
-    def stop(self, name: str, build_id: int) -> None:
+    def stop(self, name: str, build_id: Union[int, str]) -> None:
         """
         Stop specified build.
 
         Args:
-            name (str): job name or path (if in folder).
-            build_id (int): build identifier.
+            name (str):
+                Job name or path (if in folder).
+
+            build_id (int):
+                Build number or some of standard tags like `lastBuild`.
 
         Returns:
             None
@@ -152,13 +180,16 @@ class Builds:
             f'/{folder_name}/job/{job_name}/{build_id}/stop'
         )
 
-    def delete(self, name: str, build_id: int) -> None:
+    def delete(self, name: str, build_id: Union[int, str]) -> None:
         """
         Delete specified build.
 
         Args:
-            name (str): job name or path (if in folder).
-            build_id (int): build identifier.
+            name (str):
+                Job name or path (if in folder).
+
+            build_id (int):
+                Build number or some of standard tags like `lastBuild`.
 
         Returns:
             None
